﻿using SQLite;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MesDataUpload.Core.Model
{
    #region 表

    /// <summary>
    /// 数据库 扫描产品表
    /// </summary>
    [Table("feedbackprofile")]
    public class Db_FeedbackProfile
    {
        [Key]
        [PropertyIndex(0)]
        public Int64 ID { get; set; }

        /// <summary>
        /// 在 测厚仪数据库中的 profile 表的 ID
        /// </summary>
        [PropertyIndex(1)]
        public Int64 ProfileID { get; set; }


        /// <summary>
        /// 从测厚仪数据库 获取的 产品名称
        /// </summary>
        [PropertyIndex(2)]
        public string PName { get; set; }

        [PropertyIndex(3)]
        public string Batch { get; set; }

        [PropertyIndex(4)]
        public string Number { get; set; }

        [PropertyIndex(5)]
        public int BSD { get; set; }

        [PropertyIndex(6)]
        public DateTime StartTime { get; set; }

        [PropertyIndex(7)]
        public DateTime EndTime { get; set; }

        [PropertyIndex(8)]
        public bool IsFinished { get; set; }

        [PropertyIndex(9)]
        public double Target { get; set; }

        [PropertyIndex(10)]
        public double Tolerance { get; set; }

        [PropertyIndex(11)]
        public double CtrlLine { get; set; }

        [PropertyIndex(12)]
        public double Deadband { get; set; }

        /// <summary>
        /// 一定出烘箱的长度,单位m
        /// </summary>
        [PropertyIndex(13)]
        public double OutOfOven { get; set; }

        /// <summary>
        /// 控制周期,单位m
        /// </summary>
        [PropertyIndex(14)]
        public double CtrlInterval { get; set; }


        /// <summary>
        /// 平均泵速
        /// </summary>
        [PropertyIndex(15)]
        public double AvgPump { get; set; }
        /// <summary>
        /// 平均左刀
        /// </summary>
        [PropertyIndex(16)]
        public int AvgLeftDis { get; set; }
        /// <summary>
        /// 平均右刀
        /// </summary>
        [PropertyIndex(17)]
        public int AvgRightDis { get; set; }

    }

    [Table("feedbackdata")]
    public class Db_FeedbackData
    {
        [Key]
        [PropertyIndex(0)]
        public Int64 ID { get; set; }
        /// <summary>
        /// Db_FeedbackProfile 的 ID， master id
        /// </summary>
        [PropertyIndex(1)]
        public Int64 FeedbackProfileID { get; set; }
        /// <summary>
        /// 测厚仪数据库中 扫描数据的ID，用于联表
        /// </summary>
        [PropertyIndex(2)]
        public Int64 ScanData_ID { get; set; }
        /// <summary>
        /// 测量时间
        /// </summary>
        [PropertyIndex(3)]
        public DateTime Time { get; set; }
        /// <summary>
        /// 纵向位置 m, 小数点后2位
        /// </summary>
        [PropertyIndex(4)]
        public double Position { get; set; }
        /// <summary>
        /// 速度 m/min
        /// </summary>
        [PropertyIndex(5)]
        public double Velocity { get; set; }

        /// <summary>
        /// 平均值
        /// </summary>
        [PropertyIndex(6)]
        public double Avg { get; set; }

        /// <summary>
        /// 左均值
        /// </summary>
        [PropertyIndex(7)]
        public double LAvg { get; set; }

        /// <summary>
        /// 右均值
        /// </summary>
        [PropertyIndex(8)]
        public double RAvg { get; set; }

        /// <summary>
        /// 泵速
        /// </summary>
        [PropertyIndex(9)]
        public double Pump { get; set; }
        /// <summary>
        /// 当前左刀
        /// </summary>
        [PropertyIndex(10)]
        public int LeftDis { get; set; }

        /// <summary>
        /// 当前右刀
        /// </summary>
        [PropertyIndex(11)]
        public int RightDis { get; set; }

        /// <summary>
        /// 自控启动
        /// </summary>
        [PropertyIndex(12)]
        public bool IsAuto { get; set; }

        [PropertyIndex(13)]
        public DateTime ExpectTime { get; set; }
        /// <summary>
        /// 经过运算，期待输出 的泵速
        /// </summary>
        [PropertyIndex(14)]
        public double ExpectPumpOut { get; set; }
        /// <summary>
        /// 经过运算，期待输出 的左刀间距
        /// </summary>
        [PropertyIndex(15)]
        public int ExpectLeftOut { get; set; }
        /// <summary>
        /// 经过运算，期待输出 的右刀间距
        /// </summary>
        [PropertyIndex(16)]
        public int ExpectRightOut { get; set; }


        /// <summary>
        /// 计算结果
        /// </summary>
        [PropertyIndex(17)]
        public string Msg { get; set; }

        /// <summary>
        /// 非计算中
        /// </summary>
        [PropertyIndex(18)]
        public bool IsError { get; set; }
        /// <summary>
        /// 预测平均值
        /// </summary>
        [PropertyIndex(19)]
        public double PreAvg { get; set; }
        /// <summary>
        /// 预测左平均值
        /// </summary>
        [PropertyIndex(20)]
        public double PreLAvg { get; set; }
        /// <summary>
        /// 预计算右平均值
        /// </summary>
        [PropertyIndex(21)]
        public double PreRAvg { get; set; }

    }


    #endregion
}
